# Tea Django

Is a set of helper modules for developing command line, web and gui
applications using the django framework.

It's just a personal collection of modules that I found myself copying from
project to project.


## Installation


```bash
pip install tea-django
```

Add `tea_django` to `INSTALLED_APPS`:

```python

INSTALLED_APPS = [
    ...,
    "tea_django",
    ...,
]
```